summaryrefslogtreecommitdiffstats
path: root/database
diff options
context:
space:
mode:
authorDimitris Apostolou <dimitris.apostolou@icloud.com>2021-11-16 09:18:43 +0200
committerGitHub <noreply@github.com>2021-11-16 10:18:43 +0300
commitacca8c24f229da0ff0238921ebc4b30ddc7125ea (patch)
tree93113595d01b209c62167aa7d0ccaf05bb665218 /database
parent97a13e03612b0d4f2908be57b5114d619626f66d (diff)
Fix typos (#11782)
Co-authored-by: ilyam8 <ilya@netdata.cloud>
Diffstat (limited to 'database')
-rw-r--r--database/rrdhost.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/database/rrdhost.c b/database/rrdhost.c
index 13f4259be9..ad81d0e995 100644
--- a/database/rrdhost.c
+++ b/database/rrdhost.c
@@ -679,12 +679,12 @@ restart_after_removal:
int rrd_init(char *hostname, struct rrdhost_system_info *system_info) {
rrdset_free_obsolete_time = config_get_number(CONFIG_SECTION_GLOBAL, "cleanup obsolete charts after seconds", rrdset_free_obsolete_time);
// Current chart locking and invalidation scheme doesn't prevent Netdata from segmentaion faults if a short
// cleanup delay is set. Extensive stress tests showed that 10 seconds is quite a safe delay. Look at
// https://github.com/netdata/netdata/pull/11222#issuecomment-868367920 for more information.
if (rrdset_free_obsolete_time < 10) {
rrdset_free_obsolete_time = 10;
- info("The \"cleanup obsolete charts after seconds\" option was set to 10 seconds. A lower delay can potentially cause a segmentaion fault.");
+ info("The \"cleanup obsolete charts after seconds\" option was set to 10 seconds. A lower delay can potentially cause a segmentation fault.");
}
gap_when_lost_iterations_above = (int)config_get_number(CONFIG_SECTION_GLOBAL, "gap when lost iterations above", gap_when_lost_iterations_above);
if (gap_when_lost_iterations_above < 1)
@@ -679,12 +679,12 @@ restart_after_removal:
int rrd_init(char *hostname, struct rrdhost_system_info *system_info) {
rrdset_free_obsolete_time = config_get_number(CONFIG_SECTION_GLOBAL, "cleanup obsolete charts after seconds", rrdset_free_obsolete_time);
- // Current chart locking and invalidation scheme doesn't prevent Netdata from segmentaion faults if a short
+ // Current chart locking and invalidation scheme doesn't prevent Netdata from segmentation faults if a short
// cleanup delay is set. Extensive stress tests showed that 10 seconds is quite a safe delay. Look at
// https://github.com/netdata/netdata/pull/11222#issuecomment-868367920 for more information.